
#include-once

;### MathEx2DS_SingleCircle ################################################################################################
;Syntax ..................: MathEx2DS_SingleCircle($Diameter, $Degree)
;Beschreibung ............: Gibt eine bestimmte Koordinate eines Kreises anhand eines Winkels zurck
;Variablen ...............: $Diameter			Der Durchmesser des Kreises
;							$Degree				Der Winkel des Punktes auf dem Kreis (0 - 360)
;Rckgabe ................: Erfolg:				Ein 1-dimensionales Array mit den Koordinaten ([0] = x, [1] = y)
;							Fehler:				0, setzt @error
;							@error:				1 	$Diameter ist keine Zahl
;												2	$Degree ist keine Zahl oder kleiner als 0 oder grer als 360
;Bemerkungen .............: Siehe MathExPla_Circle_GetCoordinate
;###########################################################################################################################
Func MathEx2DS_SingleCircle($Diameter, $Degree)
   If Not IsNumber($Diameter) Then
	  SetError(1)
	  Return 0
   EndIf
   If Not IsNumber($Degree) Or $Degree < 0 Or $Degree > 360 Then
	  SetError(2)
	  Return 0
   EndIf
   Dim $return[2]
   $Radius = $Diameter/2
   $return[1] = (Sin($MATHEX_CONST_RADIAN*$degree)*$Radius)
   $return[0] = (Cos($MATHEX_CONST_RADIAN*$degree)*$Radius)
   Return $return
EndFunc ;==> MathEx2DS_SingleCircle

;### MathEx2DS_CompleteCircle ##############################################################################################
;Syntax ..................: MathEx2DS_CompleteCircle($Diameter, $Amount[, $Scalex = 1[, $Scaley = 1]])
;Beschreibung ............: Gibt alle Koordinaten eines Kreises zurck
;Variablen ...............: $Diameter			Der Durchmesser des Kreises
;							$Amount				Die Anzahl der zurckzugebenden Koordinaten
;							$Scalex = 1			Streckfaktor zu x
;							$Scaley = 1			Streckfaktor zu y
;Rckgabe ................: Erfolg:				Ein 2-dimensionales Array mit den Koordinaten ([n][0] = x, [n][1] = y) Die
;												Gre vom Array steht im Wert [0][0]
;							Fehler:				0, setzt @error
;							@error:				1 	$Diameter ist keine Zahl
;												2	$Amount ist keine ganze Zahl oder ist keine Zahl
;												3	Scalex ist keine Zahl
;												4	Scaley ist keine Zahl
;###########################################################################################################################
Func MathEx2DS_CompleteCircle($Diameter, $Amount, $Scalex = 1, $Scaley = 1)
   If Not IsNumber($Diameter) Then
	  SetError(1)
	  Return 0
   EndIf
   If Not IsInt($Amount) Or Not IsNumber($Amount) Then
	  SetError(2)
	  Return 0
   EndIf
   If Not IsNumber($Scalex) Then
	  SetError(3)
	  Return 0
   EndIf
   If Not IsNumber($Scaley) Then
	  SetError(4)
	  Return 0
   EndIf
   Dim $return[$Amount+1][2]
   $degree = 360/$Amount
   $return[0][0] = $Amount
   For $i = 1 To $Amount
	  $Coords=MathEx2DS_SingleCircle($Diameter, $Degree*$i)
	  $return[$i][0] = $Coords[0]
	  $return[$i][1] = $Coords[1]
   Next
   Return MathEx2DS_Scale($return, $Scalex, $Scaley)
EndFunc ;==> MathEx2DS_AllCircle

;### MathEx2DS_Mirror ######################################################################################################
;Syntax ..................: MathEx2DS_Mirror($hArray, $Mirrorx = False, $Mirrory = False)
;Beschreibung ............: Spiegelt die zurckgegebenen Koordinaten
;Variablen ...............: $hArray				Der Rckgabewert einer Funktion
;							$Mirrorx = False	Wert, ob auf der x-Achse gespiegelt werden soll
;							$Mirrory = False	Wert, ob auf der y-Achse gespiegelt werden soll
;Rckgabe ................: Erfolg:				Ein 2-dimensionales Array mit den Koordinaten ([n][0] = x, [n][1] = y) Die Gre
;												vom Array steht im Wert [0][0]
;							Fehler:				0, setzt @error
;							@error:				1 	$hArray ist kein Array
;												2	$Mirrorx ist kein Boolescher Wert
;												3	$Mirrory ist kein Boolescher Wert
;Bemerkungen .............: Es kann zu einem Fehlerhaften Spiegeln kommen, wenn die Werte des Arrays selber verndert
;							wurden. Ich rate zur Vorsicht beim Bearbeiten von dem Koordinatenarray.
;###########################################################################################################################
Func MathEx2DS_Mirror($hArray, $Mirrorx = False, $Mirrory = False)
   If Not IsArray($hArray) Then
	  SetError(1)
	  Return 0
   EndIf
   If Not IsBool($Mirrorx) Then
	  SetError(2)
	  Return 0
   EndIf
   If Not IsBool($Mirrory) Then
	  SetError(3)
	  Return 0
   EndIf
   $return = $hArray
   For $i = 1 To $hArray[0][0]
	 If $Mirrorx = True Then $return[$i][0] = -$return[$i][0]
	 If $Mirrory = True Then $return[$i][1] = -$return[$i][1]
   Next
   Return $return
EndFunc ;==> MathEx2DS_Mirror

;### MathEx2DS_Parable #####################################################################################################
;Syntax ..................: MathEx2DS_Parable($Width, $Height, $Area[, $Scalex = 1[, $Scaley = 1]])
;Beschreibung ............: Gibt Koordinaten einer Parabel zurck
;Variablen ...............: $Width				Der Faktor fr die Breite der Parabel
;							$Height				Der Faktor fr die Hhe der Parabel
;							$Area				Der Bereich, von welchem Wert die Koordinaten anfangen und aufhren soll
;							$Scalex = 1			Streckfaktor zu x
;							$Scaley = 1			Streckfaktor zu y
;Rckgabe ................: Erfolg:				Ein 2-dimensionales Array mit den Koordinaten ([n][0] = x, [n][1] = y) Die
;												Gre vom Array steht im Wert [0][0]
;							Fehler:				0, setzt @error
;							@error:				1 	$Width ist keine Zahl
;												2	$Height ist keine Zahl
;												3	$Area ist keine gerade Zahl oder ist keine Zahl
;												4	$Scalex ist keine Zahl
;												5	$Scaley ist keine Zahl
;###########################################################################################################################
Func MathEx2DS_Parable($Width, $Height, $Area, $Scalex = 1, $Scaley = 1)
   If Not IsNumber($Width) Then
	  SetError(1)
	  Return 0)
   EndIf
   If Not IsNumber($Height) Then
	  SetError(2)
	  Return 0)
   EndIf
   If Not IsInt($Area) Or Not IsNumber($Area) Then
	  SetError(3)
	  Return 0)
   EndIf
   If Not IsInt($Scalex) Then
	  SetError(4)
	  Return 0)
   EndIf
   If Not IsInt($Scaley) Then
	  SetError(5)
	  Return 0)
   EndIf
   $ArrayArea = ($Area*2+1)
   Dim $return[$ArrayArea+1][2]
   $return[0][0] = $ArrayArea
   $j = 1
   For $i = -$Area To $Area
	  $return[$j][0] = ($i)*$Width
	  $return[$j][1] = (MathExBas_Power($i)*$Height)
	  $j+=1
   Next
   Return MathEx2DS_Scale($return, $Scalex, $Scaley)
EndFunc ;==> MathEx2DS_Parable

;### MathEx2DS_Scale #######################################################################################################
;Syntax ..................: MathEx2DS_Mirror($hArray, $Mirrorx = False, $Mirrory = False)
;Beschreibung ............: Spiegelt die zurckgegebenen Koordinaten
;Variablen ...............: $hArray				Der Rckgabewert einer Funktion
;							$Scalex				Streckfaktor zu x
;							$Scaley				Streckfaktor zu y
;Rckgabe ................: Erfolg:				Ein 2-dimensionales Array mit den Koordinaten ([n][0] = x, [n][1] = y) Die Gre
;												vom Array steht im Wert [0][0]
;							Fehler:				0, setzt @error
;							@error:				1 	$hArray ist kein Array
;												2	$Scalex ist keie Zahl Wert
;												3	$Scaley ist keie Zahl Wert
;Bemerkungen .............: Es kann zu einem Fehlerhaften Spiegeln kommen, wenn die Werte des Arrays selber verndert
;							wurden. Ich rate zur Vorsicht beim Bearbeiten von dem Koordinatenarray.
;###########################################################################################################################
Func MathEx2DS_Scale($hArray, $Scalex, $Scaley)
   If Not IsArray($hArray) Then
	  SetError(1)
	  Return 0
   EndIf
   If Not IsNumber($Scalex) Then
	  SetError(2)
	  Return 0
   EndIf
   If Not IsNumber($Scaley) Then
	  SetError(3)
	  Return 0
   EndIf
   For $i=1 To $hArray[0][0]
	  $hArray[$i][0] *= $Scalex
	  $hArray[$i][1] *= $Scaley
   Next
   Return $hArray
EndFunc ;==> MathEx2DS_Scale
