
#include-once

;### MathEx3DS_SingleSphere ################################################################################################
;Syntax ..................: MathEx3DS_SingleSphere($Radius, $Theta, $Phi)
;Beschreibung ............: Gibt eine bestimmte Koordinate einer Kugel zurck
;Variablen ...............: $Radius				Der Radius der Kugel
;							$Theta				Der Winkel Theta von dem Punkt (0 - 180)
;							$Phi				Der Winkel Phi von dem Punkt (0 - 360)
;Rckgabe ................: Erfolg:				Ein 1-dimensionales Array mit den Koordinaten ([0] = x, [1] = y, [2] = z)
;							Fehler:				0, setzt @error
;							@error:				1	$Radius ist keine Zahl
;												2 	$Theta ist grer als 180 oder ist keine Zahl
;												3	$Phi ist grer als 360 oder ist keine Zahl
;Bemerkungen .............: Um zu verstehen, warum man nur zwei Winkel braucht, um einen Punkt zu bestimmen, muss man
;							zunchst wissen, was Theta ist: Es ist der Winkel Parallel zur y-Achse. Er geht von ganz oben
;							(0) bis ganz unten (180). Phi ist der Winkel, der Parallel zum "quator" liegt. Er spricht den
;							Kreis von x- und z-Achse an. Weitere Informationen zu dem Thema auf Wikipedia unter dem Thema
;							"Kugelkoordinaten".
;###########################################################################################################################
Func MathEx3DS_SingleSphere($Radius, $Theta, $Phi)
   If Not IsNumber($Radius) Then
	  SetError(1)
	  Return 0
   EndIf
   If $Theta > 180 Or Not IsNumber($Theta) Then
	  SetError(2)
	  Return 0
   EndIf
   If $Phi > 360 Or Not IsNumber($Phi) Then
	  SetError(3)
	  Return 0
   EndIf
   Dim $return[3]
   $return[0] = $Radius*Sin($Theta*$MATHEX_CONST_RADIAN)*Sin($Phi*$MATHEX_CONST_RADIAN)	;eigentlich y jetzt aber x
   $return[1] = $Radius*Cos($Theta*$MATHEX_CONST_RADIAN)								;eigentlich z jetzt aber y
   $return[2] = $Radius*Sin($Theta*$MATHEX_CONST_RADIAN)*Cos($Phi*$MATHEX_CONST_RADIAN)	;eigentlich x jetzt aber z
   Return $return
EndFunc ;==> MathEx3DS_SingleSphere

;### MathEx3DS_CompleteSphere ##############################################################################################
;Syntax ..................: MathEx3DS_CompleteSphere($Radius, $Split[, $Scalex = 1[, $Scaley = 1[, $Scalez = 1]]])
;Beschreibung ............: Gibt alle Koordinaten einer Kugel zurck
;Variablen ...............: $Radius				Der Radius der Kugel
;							$Split				Gibt an, wie fiele horizontale/verticale Trennungen die Kugel hat
;							$Scalex = 1			Streckfaktor zu x
;							$Scaley = 1			Streckfaktor zu y
;							$Scalez = 1			Streckfaktor zu z
;Rckgabe ................: Erfolg:				Ein 2-dimensionales Array mit den Koordinaten ([n][0] = x, [n][1] = y,
;												[n][2] = z) Die Gre vom Array muss mit UBound ermittelt werden
;							Fehler:				0, setzt @error
;							@error:				1 	$Radius ist keine Zahl
;												2	$Split ist keine Zahl oder keine ganze Zahl
;												3	$Scalex ist keine Zahl
;												4	$Scalex ist keine Zahl
;												5	$Scalex ist keine Zahl
;###########################################################################################################################
Func MathEx3DS_CompleteSphere($Radius, $Split, $Scalex = 1, $Scaley = 1, $Scalez = 1)
   If Not IsNumber($Radius) Then
	  SetError(1)
	  Return 0
   EndIf
   If Not IsInt($Split) Or Not IsNumber($Split) Then
	  SetError(2)
	  Return 0
   EndIf
   If Not IsNumber($Scalex) Then
	  SetError(3)
	  Return 0
   EndIf
   If Not IsNumber($Scaley) Then
	  SetError(4)
	  Return 0
   EndIf
   If Not IsNumber($Scalez) Then
	  SetError(5)
	  Return 0
   EndIf
   $theta = 180/($Split/2)
   $phi = 360/$Split
   $range = 0
   For $t = 0 To 180 Step $theta
	  For $p = 0 to 360 Step $phi
		 $range += 1
	  Next
   Next
   Dim $return[$range][3]
   $i = 0
   For $t = 0 To 180 Step $theta
	  For $p = 0 to 360 Step $phi
		 $Coords = MathEx3DS_SingleSphere($Radius, $t, $p)
		 $return[$i][0] = $Coords[0]
		 $return[$i][1] = $Coords[1]
		 $return[$i][2] = $Coords[2]
		 $i+=1
	  Next
   Next
   Return MathEx3DS_Scale($return, $Scalex, $Scaley, $Scalez)
EndFunc ;==> MathEx3DS_CompleteSphere

;### MathEx3DS_SphereRadiusAndAngle ########################################################################################
;Syntax ..................: MathEx3DS_SphereRadiusAndAngle($cX, $cY, $cZ, $pX, $pY, $pZ)
;Beschreibung ............: Gibt den Radius und die Winkel zu einem Punkt, relativ zu einem Mittelpunkt zurck
;Variablen ...............: $cX					Mittelpunkt zu x
;							$cY					Mittelpunkt zu y
;							$cZ					Mittelpunkt zu z
;							$pX					 	
;							$pY					Punkt y
;							$pZ					Punkt z
;Rckgabe ................: Erfolg:				Ein Array mit folgenden Format:
;												[0]	Radius
;												[1]	Der Winkel Theta von dem Punkt (0 - 180)
;												[2]	Der Winkel Phi von dem Punkt (0 - 360)
;							Fehler:				0, setzt @error
;							@error:				1	$cX ist keine Zahl
;												2	$cY ist keine Zahl
;												3	$cZ ist keine Zahl
;												4	$pX ist keine Zahl
;												5	$pY ist keine Zahl
;												6	$pZ ist keine Zahl
;Bemerkungen .............: Siehe auch MathEx3DS_SingleSphere
;###########################################################################################################################
Func MathEx3DS_SphereRadiusAndAngle($cX, $cY, $cZ, $pX, $pY, $pZ)
   If Not IsNumber($cX) Then
	  SetError(1)
	  Return 0
   EndIf
   If Not IsNumber($cY) Then
	  SetError(2)
	  Return 0
   EndIf
   If Not IsNumber($cZ) Then
	  SetError(3)
	  Return 0
   EndIf
   If Not IsNumber($pX) Then
	  SetError(4)
	  Return 0
   EndIf
   If Not IsNumber($pY) Then
	  SetError(5)
	  Return 0
   EndIf
   If Not IsNumber($pZ) Then
	  SetError(6)
	  Return 0
   EndIf
   Dim $Return[3]
   $Width=$pX-$cX
   $Height=$pY-$cY
   $Depth=$pZ-$cZ
   $Radius=MathExSTE_Cuboid_GetRoomDiagonal($Width, $Height, $Depth)
   ;ATan
   $Phi=_Degree(_ATan2($Height,$Width))
   $Theta=_Degree(_ATan2($Width,$Depth))
   $Return[0]=$Radius
   $Return[1]=$Theta
   $Return[2]=$Phi
   Return $Return
EndFunc ;==> MathEx3DS_SphereRadiusAndAngle

;### MathEx3DS_Cube ########################################################################################################
;Syntax ..................: MathEx3DS_Cube($Size[, $Scalex=1[, $Scaley = 1[, $Scalez = 1]]])
;Beschreibung ............: Gibt die Koordinaten eines Wrfels zurck
;Variablen ...............: $Size				Die Gre des Wrfels
;							$Scalex = 1			Streckfaktor zu x
;							$Scaley = 1			Streckfaktor zu y
;							$Scalez = 1			Streckfaktor zu z
;Rckgabe ................: Erfolg:				Ein 2-dimensionales Array mit den Koordinaten ([n][0] = x, [n][1] = y,
;												[n][2] = z) Die Gre vom Array muss mit UBound ermittelt werden ist aber
;												natrlich 8... XD
;							Fehler:				0, setzt @error
;							@error:				1 	$Size ist keine Zahl
;												2	$Scalex ist keine Zahl
;												3	$Scaley ist keine Zahl
;												4	$Scalez ist keine Zahl
;###########################################################################################################################
Func MathEx3DS_Cube($Size, $Scalex=1, $Scaley = 1, $Scalez = 1)
   If Not IsNumber($Size) Then
	  SetError(1)
	  Return 0
   EndIf
   If Not IsNumber($Scalex) Then
	  SetError(2)
	  Return 0
   EndIf
   If Not IsNumber($Scaley) Then
	  SetError(3)
	  Return 0
   EndIf
   If Not IsNumber($Scalez) Then
	  SetError(4)
	  Return 0
   EndIf
   Dim $return[8][3]
   $Distance = $Size/2
   $i = 0
   For $x = -$Distance To $Distance Step $Size
	  For $y = -$Distance To $Distance Step $Size
		 For $z = -$Distance To $Distance Step $Size
			$return[$i][0] = $x
			$return[$i][1] = $y
			$return[$i][2] = $z
			$i=$i+1
		 Next
	  Next
   Next
   Return MathEx3DS_Scale($return, $Scalex, $Scaley, $Scalez)
EndFunc ;==> MathEx3DS_Cube

;### MathEx3DS_Cylinder ####################################################################################################
;Syntax ..................: MathEx3DS_Cylinder($Diameter, $Height, $Amount[, $VSplit = 2[, $Scalex = 1[, $Scaley = 1[, $Scalez = 1]]]])
;Beschreibung ............: Gibt die Koordinaten eines Zylinders zurck
;Variablen ...............: $Diameter			Der Durchmesser der einzelnen Kreise
;							$Height				Die Hhe des Zylinders
;							$Amount				Die Anzahl der Punkte innerhalb eines Kreises
;							$VSplit=2			Die Anzahl der Kreise (minimal 2)
;							$Scalex = 1			Streckfaktor zu x
;							$Scaley = 1			Streckfaktor zu y
;							$Scalez = 1			Streckfaktor zu z
;Rckgabe ................: Erfolg:				Ein 2-dimensionales Array mit den Koordinaten ([n][0] = x, [n][1] = y,
;												[n][2] = z) Die Gre vom Array muss mit UBound ermittelt werden
;							Fehler:				0, setzt @error
;							@error:				1 	$Diameter ist keine Zahl
;												2	$Height ist keine Zahl
;												3	$Amount ist keine ganze Zahl oder ist keine Zahl
;												4	$VSplit ist keine ganze Zahl oder kleiner als 2 oder ist keine Zahl
;												5	$Scalex ist keine Zahl
;												6	$Scaley ist keine Zahl
;												7	$Scalez ist keine Zahl
;###########################################################################################################################
Func MathEx3DS_Cylinder($Diameter, $Height, $Amount, $VSplit = 2, $Scalex = 1, $Scaley = 1, $Scalez = 1)
   If Not IsNumber($Diameter) Then
	  SetError(1)
	  Return 0
   EndIf
   If Not IsNumber($Height) Then
	  SetError(2)
	  Return 0
   EndIf
   If Not IsInt($Amount) Or Not IsNumber($Amount) Then
	  SetError(3)
	  Return 0
   EndIf
   If Not IsInt($VSplit) Or Not IsNumber($VSplit) Or $VSplit<2 Then
	  SetError(4)
	  Return 0
   EndIf
   If Not IsNumber($Scalex) Then
	  SetError(5)
	  Return 0
   EndIf
   If Not IsNumber($Scaley) Then
	  SetError(6)
	  Return 0
   EndIf
   If Not IsNumber($Scalez) Then
	  SetError(7)
	  Return 0
   EndIf
   $range = ($VSplit*$Amount)+1
   Dim $return[$range-1][3]
   $circle = MathEx2DS_CompleteCircle($Diameter,$Amount)
   $h = -$Height/2
   $hstep = $Height/$VSplit
   $i = 0
   While True
	  For $c = 1 To $Amount
		 $return[$i][0] = $circle[$c][0]
		 $return[$i][1] = $h
		 $return[$i][2] = $circle[$c][1]
		 $i = $i+1
		 If $i = $range-1 Then ExitLoop
	  Next
	  If $i = $range-1 Then ExitLoop
	  $h = $h+$hstep
   WEnd
   Return MathEx3DS_Scale($return,$Scalex,$Scaley,$Scalez)
EndFunc ;==> MathEx3DS_Cylinder

;### MathEx3DS_Cone ########################################################################################################
;Syntax ..................: MathEx3DS_Cone($Diameter, $Height, $Amount[, $VSplit = 2[, $Scalex = 1[, $Scaley = 1[, $Scalez = 1]]]])
;Beschreibung ............: Gibt die Koordinaten eines Kegels zurck
;Variablen ...............: $Diameter			Der Durchmesser des grten Kreises
;							$Height				Die Hhe des Kegels
;							$Amount				Die Anzahl der Punkte innerhalb eines Kreises
;							$VSplit=2			Die Anzahl der Kreise (minimal 2)
;							$Scalex = 1			Streckfaktor zu x
;							$Scaley = 1			Streckfaktor zu y
;							$Scalez = 1			Streckfaktor zu z
;Rckgabe ................: Erfolg:				Ein 2-dimensionales Array mit den Koordinaten ([n][0] = x, [n][1] = y,
;												[n][2] = z) Die Gre vom Array muss mit UBound ermittelt werden
;							Fehler:				0, setzt @error
;							@error:				1 	$Diameter ist keine Zahl
;												2	$Height ist keine Zahl
;												3	$Amount ist keine ganze Zahl oder ist keine Zahl
;												4	$VSplit ist keine ganze Zahl oder kleiner als 2 oder ist keine Zahl
;												5	$Scalex ist keine Zahl
;												6	$Scaley ist keine Zahl
;												7	$Scalez ist keine Zahl
;###########################################################################################################################
Func MathEx3DS_Cone($Diameter, $Height, $Amount, $VSplit = 2, $Scalex = 1, $Scaley = 1, $Scalez = 1)
   If Not IsInt($Amount) Then
	  SetError(1)
	  Return 0
   EndIf
   If Not IsInt($VSplit) Then
	  SetError(2)
	  Return 0
   EndIf
   $DiameterStep = $Diameter/$VSplit
   $range = ($VSplit*$Amount)-$Amount+2
   Dim $return[$range-1][3]
   $h = -$Height/2
   $hstep = $Height/$VSplit
   $i = 0
   $Diameter = 0
   While True
	  $circle = MathEx2DS_CompleteCircle($Diameter,$Amount)
	  For $c = 1 To $Amount
		 $return[$i][0] = $circle[$c][0]
		 $return[$i][1] = $h
		 $return[$i][2] = $circle[$c][1]
		 $i = $i+1
		 If $Diameter = 0 Then ExitLoop
		 If $i = $range-1 Then ExitLoop
	  Next
	  If $i = $range-1 Then ExitLoop
	  $h = $h+$hstep
	  $Diameter += $DiameterStep
   WEnd
   Return MathEx3DS_Scale($return, $Scalex, $Scaley, $Scalez)
EndFunc ;==> MathEx3DS_Cone

;### MathEx3DS_Scale #######################################################################################################
;Syntax ..................: MathEx3DS_Scale($hArray, $Scalex, $Scaley, $Scalez)
;Beschreibung ............: Streckt die zurckgegebenen Koordinaten
;Variablen ...............: $Array				Der Rckgabewert einer Funktion
;							$Scalex = 1			Streckfaktor zu x
;							$Scaley = 1			Streckfaktor zu y
;							$Scalez = 1			Streckfaktor zu z
;Rckgabe ................: Erfolg:				Ein 2-dimensionales Array mit den Koordinaten ([n][0] = x, [n][1] = y,
;												[n][2] = z) Die Gre vom Array muss mit UBound ermittelt werden
;							Fehler:				0, setzt @error
;							@error:				1 	$hArray ist kein Array
;												2	$Scalex ist keine Zahl
;												3	$Scaley ist keine Zahl
;												4	$Scalez ist keine Zahl
;Bemerkungen .............: Es kann zu einem Fehlerhaften Strecken kommen, wenn die Werte des Arrays selber	verndert
;							wurden. Ich rate zur Vorsicht beim Bearbeiten von dem Array.
;###########################################################################################################################
Func MathEx3DS_Scale($hArray, $Scalex, $Scaley, $Scalez)
   If Not IsArray($hArray) Then
	  SetError(1)
	  Return 0
   EndIf
   If Not IsNumber($Scalex) Then
	  SetError(2)
	  Return 0
   EndIf
   If Not IsNumber($Scaley) Then
	  SetError(3)
	  Return 0
   EndIf
   If Not IsNumber($Scalez) Then
	  SetError(4)
	  Return 0
   EndIf
   For $i = 0 To UBound($hArray)-1
	  $hArray[$i][0] = $hArray[$i][0]*$Scalex
	  $hArray[$i][1] = $hArray[$i][1]*$Scaley
	  $hArray[$i][2] = $hArray[$i][2]*$Scalez
   Next
   Return $hArray
EndFunc ;==> MathEx3DS_Scale

;### MathEx3DS_Mirror ######################################################################################################
;Syntax ..................: MathEx3DS_Scale($hArray, $Scalex, $Scaley, $Scalez)
;Beschreibung ............: Spiegelt die zurckgegebenen Koordinaten
;Variablen ...............: $Array				Der Rckgabewert einer Funktion
;							$Mirrorx = False	Wert, ob auf der z-Achse gespiegelt werden soll
;							$Mirrory = False	Wert, ob auf der y-Achse gespiegelt werden soll
;							$Mirrorz = False	Wert, ob auf der z-Achse gespiegelt werden soll
;Rckgabe ................: Erfolg:				Ein 2-dimensionales Array mit den Koordinaten ([n][0] = x, [n][1] = y,
;												[n][2] = z) Die Gre vom Array muss mit UBound ermittelt werden
;							Fehler:				0, setzt @error
;							@error:				1 	$hArray ist kein Array
;												2	$Mirrorx ist keine Zahl
;												3	$Mirrory ist keine Zahl
;												4	$Mirrorz ist keine Zahl
;Bemerkungen .............: Es kann zu einem Fehlerhaften Spiegeln kommen, wenn die Werte des Arrays selber	verndert
;							wurden. Ich rate zur Vorsicht beim Bearbeiten von dem Array.
;###########################################################################################################################
Func MathEx3DS_Mirror($hArray, $Mirrorx = False, $Mirrory = False, $Mirrorz = False)
   If Not IsArray($hArray) Then
	  SetError(1)
	  Return 0
   EndIf
   If Not IsBool($Mirrorx) Then
	  SetError(2)
	  Return 0
   EndIf
   If Not IsBool($Mirrory) Then
	  SetError(3)
	  Return 0
   EndIf
   If Not IsBool($Mirrorz) Then
	  SetError(4)
	  Return 0
   EndIf
   $return = $hArray
   For $i = 0 To UBound($hArray)-1
	 If $Mirrorx = True Then $return[$i][0] = -$return[$i][0]
	 If $Mirrory = True Then $return[$i][1] = -$return[$i][1]
	 If $Mirrorz = True Then $return[$i][2] = -$return[$i][2]
   Next
   Return $return
EndFunc ;==> MathEx3DS_Mirror