
#include-once

;### MathExSTE_Sphere_GetSurface ###########################################################################################
;Syntax ..................: MathExSTE_Sphere_GetSurface($Radius)
;Beschreibung ............: Gibt die Oberflche einer Kugel zurck
;Variablen ...............: $Radius				Der Radius der Kugel
;Rckgabe ................: Erfolg:				Die Oberflche der Kugel
;							Fehler:				0, setzt @error
;							@error:				1 	$Radius ist keine Zahl
;###########################################################################################################################
Func MathExSTE_Sphere_GetSurface($Radius)
   If Not IsNumber($Radius) Then
	  SetError(1)
	  Return 0
   EndIf
   Return 4*$MATHEX_CONST_PI*MathExBas_Power($Radius)
EndFunc ;==> MathExSTE_Sphere_GetSurface

;### MathExSTE_Sphere_GetVolume ############################################################################################
;Syntax ..................: MathExSTE_Sphere_GetVolume($Radius)
;Beschreibung ............: Gibt das Volumen einer Kugel zurck
;Variablen ...............: $Radius				Der Radius der Kugel
;Rckgabe ................: Erfolg:				Das Volumen der Kugel
;							Fehler:				0, setzt @error
;							@error:				1 	$Radius ist keine Zahl
;###########################################################################################################################
Func MathExSTE_Sphere_GetVolume($Radius)
   If Not IsNumber($Radius) Then
	  SetError(1)
	  Return 0
   EndIf
   Return 4/3*$MATHEX_CONST_PI*MathExBas_Power($Radius,3)
EndFunc ;==> MathExSTE_Sphere_GetVolume

;### MathExSTE_Sphere_GetCoordinate ########################################################################################
;Syntax ..................: MathExSTE_Sphere_GetCoordinate($Radius, $Theta, $Phi)
;Beschreibung ............: Gibt eine bestimmte Koordinate einer Kugel zurck
;Variablen ...............: $Radius				Der Radius der Kugel
;							$Theta				Der Winkel Theta von dem Punkt (0 - 180)
;							$Phi				Der Winkel Phi von dem Punkt (0 - 360)
;Rckgabe ................: Erfolg:				Ein 1-dimensionales Array mit den Koordinaten ([0] = x, [1] = y, [2] = z)
;							Fehler:				0, setzt @error
;							@error:				1	$Radius ist keine Zahl
;												2 	$Theta ist grer als 180 oder ist keine Zahl
;												3	$Phi ist grer als 360 oder ist keine Zahl
;Bemerkungen .............: Um zu verstehen, warum man nur zwei Winkel braucht, um einen Punkt zu bestimmen, muss man
;							zunchst wissen, was Theta ist: Es ist der Winkel Parallel zur y-Achse. Er geht von ganz oben
;							(0) bis ganz unten (180). Phi ist der Winkel, der Parallel zum "quator" liegt. Er spricht den
;							Kreis von x- und z-Achse an. Weitere Informationen zu dem Thema auf Wikipedia unter dem Thema
;							"Kugelkoordinaten".
;							Siehe auch MathEx3DS_SingleSphere
;###########################################################################################################################
Func MathExSTE_Sphere_GetCoordinate($Radius, $Theta, $Phi)
   If Not IsNumber($Radius) Then
	  SetError(1)
	  Return 0
   EndIf
   If $Theta > 180 Or Not IsNumber($Theta) Then
	  SetError(2)
	  Return 0
   EndIf
   If $Phi > 360 Or Not IsNumber($Phi) Then
	  SetError(3)
	  Return 0
   EndIf
   Dim $return[3]
   $return[0] = $Radius*Sin($Theta*$MATHEX_CONST_RADIAN)*Sin($Phi*$MATHEX_CONST_RADIAN)	;eigentlich y jetzt aber x
   $return[1] = $Radius*Cos($Theta*$MATHEX_CONST_RADIAN)								;eigentlich z jetzt aber y
   $return[2] = $Radius*Sin($Theta*$MATHEX_CONST_RADIAN)*Cos($Phi*$MATHEX_CONST_RADIAN)	;eigentlich x jetzt aber z
   Return $return
EndFunc ;==> MathEx3DS_SingleSphere

;### MathExSTE_Cuboid_GetSurface ###########################################################################################
;Syntax ..................: MathExSTE_Cuboid_GetSurface($a, $b, $c)
;Beschreibung ............: Gibt die Oberflche eines Quaders zurck
;Variablen ...............: $a					Die Seitenlnge a des Quaders
;							$b					Die Seitenlnge b des Quaders
;							$c					Die Seitenlnge c des Quaders
;Rckgabe ................: Erfolg:				Die Oberflche der Quaders
;							Fehler:				0, setzt @error
;							@error:				1 	$a ist keine Zahl
;												2 	$b ist keine Zahl
;												3 	$c ist keine Zahl
;###########################################################################################################################
Func MathExSTE_Cuboid_GetSurface($a, $b, $c)
   If Not IsNumber($a) Then
	  SetError(1)
	  Return 0
   EndIf
   If Not IsNumber($b) Then
	  SetError(2)
	  Return 0
   EndIf
   If Not IsNumber($c) Then
	  SetError(3)
	  Return 0
   EndIf
   Return 2*($a*$b+$b*$c+$b*$c)
EndFunc ;==> MathExSTE_Cuboid_GetSurface

;### MathExSTE_Cuboid_GetVolume ###########################################################################################
;Syntax ..................: MathExSTE_Cuboid_GetVolume($a, $b, $c)
;Beschreibung ............: Gibt das Volumen eines Quaders zurck
;Variablen ...............: $a					Die Seitenlnge a des Quaders
;							$b					Die Seitenlnge b des Quaders
;							$c					Die Seitenlnge c des Quaders
;Rckgabe ................: Erfolg:				Das Volumen der Quaders
;							Fehler:				0, setzt @error
;							@error:				1 	$a ist keine Zahl
;												2 	$b ist keine Zahl
;												3 	$c ist keine Zahl
;###########################################################################################################################
Func MathExSTE_Cuboid_GetVolume($a, $b, $c)
   If Not IsNumber($a) Then
	  SetError(1)
	  Return 0
   EndIf
   If Not IsNumber($b) Then
	  SetError(2)
	  Return 0
   EndIf
   If Not IsNumber($c) Then
	  SetError(3)
	  Return 0
   EndIf
   Return $a*$b*$c
EndFunc ;==> MathExSTE_Cuboid_GetVolume

;### MathExSTE_Cuboid_GetRoomDiagonal ###########################################################################################
;Syntax ..................: MathExSTE_Cuboid_GetRoomDiagonal($a, $b, $c)
;Beschreibung ............: Gibt die Lnge der Raumdiagonalen zurck
;Variablen ...............: $a					Die Seitenlnge a des Quaders
;							$b					Die Seitenlnge b des Quaders
;							$c					Die Seitenlnge c des Quaders
;Rckgabe ................: Erfolg:				Die Lnge der Raumdiagonalen
;							Fehler:				0, setzt @error
;							@error:				1 	$a ist keine Zahl
;												2 	$b ist keine Zahl
;												3 	$c ist keine Zahl
;###########################################################################################################################
Func MathExSTE_Cuboid_GetRoomDiagonal($a, $b, $c)
   If Not IsNumber($a) Then
	  SetError(1)
	  Return 0
   EndIf
   If Not IsNumber($b) Then
	  SetError(2)
	  Return 0
   EndIf
   If Not IsNumber($c) Then
	  SetError(3)
	  Return 0
   EndIf
   Return Sqrt($a*$a+$b*$b+$c*$c)
EndFunc ;==> MathExSTE_Cuboid_GetRoomDiagonal

;### MathExSTE_Tetrahedron_GetSurface ######################################################################################
;Syntax ..................: MathExSTE_Tetrahedron_GetSurface($a)
;Beschreibung ............: Gibt die Oberflche eines Tetraeders zurck
;Variablen ...............: $a					Die Seitenlnge eines Tetraeders
;Rckgabe ................: Erfolg:				Die Oberflche des Tetraeders
;							Fehler:				0, setzt @error
;							@error:				1 	$a ist keine Zahl
;###########################################################################################################################
Func MathExSTE_Tetrahedron_GetSurface($a)
   If Not IsNumber($a) Then
	  SetError(1)
	  Return 0
   EndIf
   Return ($a*$a)*Sqrt(3)
EndFunc ;==> MathExSTE_Tetrahedron_GetSurface

;### MathExSTE_Tetrahedron_GetVolume #######################################################################################
;Syntax ..................: MathExSTE_Tetrahedron_GetVolume($a)
;Beschreibung ............: Gibt das Volumen eines Tetraeders zurck
;Variablen ...............: $a					Die Seitenlnge eines Tetraeders
;Rckgabe ................: Erfolg:				Das Volumen des Tetraeders
;							Fehler:				0, setzt @error
;							@error:				1 	$a ist keine Zahl
;###########################################################################################################################
Func MathExSTE_Tetrahedron_GetVolume($a)
   If Not IsNumber($a) Then
	  SetError(1)
	  Return 0
   EndIf
   Return MathExBas_Power($a,3)/12*$MATHEX_CONST_SQRT2
EndFunc ;==> MathExSTE_Tetrahedron_GetVolume

;### MathExSTE_Tetrahedron_GetHeight #######################################################################################
;Syntax ..................: MathExSTE_Tetrahedron_GetHeight($a)
;Beschreibung ............: Gibt die Hhe eines Tetraeders zurck
;Variablen ...............: $a					Die Seitenlnge eines Tetraeders
;Rckgabe ................: Erfolg:				Die Hhe des Tetraeders
;							Fehler:				0, setzt @error
;							@error:				1 	$a ist keine Zahl
;###########################################################################################################################
Func MathExSTE_Tetrahedron_GetHeight($a)
   If Not IsNumber($a) Then
	  SetError(1)
	  Return 0
   EndIf
   Return $a/3*Sqrt(6)
EndFunc ;==> MathExSTE_Tetrahedron_GetHeight

;### MathExSTE_Cylinder_GetSurface #########################################################################################
;Syntax ..................: MathExSTE_Cylinder_GetSurface($Radius, $Height)
;Beschreibung ............: Gibt die Oberflche eines Zylinders zurck
;Variablen ...............: $Radius				Der Radius des Zylinders
;							$Height				Die Hhe des Zylinders
;Rckgabe ................: Erfolg:				Die Oberflche des Zylinders
;							Fehler:				0, setzt @error
;							@error:				1 	$Radius ist keine Zahl
;												2	$Height ist keine Zahl
;###########################################################################################################################
Func MathExSTE_Cylinder_GetSurface($Radius, $Height)
   If Not IsNumber($Radius) Then
	  SetError(1)
	  Return 0
   EndIf
   If Not IsNumber($Height) Then
	  SetError(2)
	  Return 0
   EndIf
   Return 2*$MATHEX_CONST_PI*$Radius*($Height+$Radius)
EndFunc ;==> MathExSTE_Cylinder_GetSurface

;### MathExSTE_Cylinder_GetVolume ##########################################################################################
;Syntax ..................: MathExSTE_Cylinder_GetVolume($Radius, $Height)
;Beschreibung ............: Gibt das Volumen eines Zylinders zurck
;Variablen ...............: $Radius				Der Radius des Zylinders
;							$Height				Die Hhe des Zylinders
;Rckgabe ................: Erfolg:				Die Oberflche des Zylinders
;							Fehler:				0, setzt @error
;							@error:				1 	$Radius ist keine Zahl
;												2	$Height ist keine Zahl
;###########################################################################################################################
Func MathExSTE_Cylinder_GetVolume($Radius, $Height)
   If Not IsNumber($Radius) Then
	  SetError(1)
	  Return 0
   EndIf
   If Not IsNumber($Height) Then
	  SetError(2)
	  Return 0
   EndIf
   Return $Height*MathExBas_Power($Radius)*$MATHEX_CONST_PI
EndFunc ;==> MathExSTE_Cylinder_GetVolume

;### MathExSTE_QuadraticPyramid_GetSurface #################################################################################
;Syntax ..................: MathExSTE_QuadraticPyramid_GetSurface($a, $Height)
;Beschreibung ............: Gibt die Oberflche einer quadratischen Pyramide zurck
;Variablen ...............: $a					Die Kantenlnge der Grundflche der Pyramide
;							$Height				Die Hhe der Pyramide
;Rckgabe ................: Erfolg:				Die Oberflche des Zylinders
;							Fehler:				0, setzt @error
;							@error:				1 	$a ist keine Zahl
;												2	$Height ist keine Zahl
;###########################################################################################################################
Func MathExSTE_QuadraticPyramid_GetSurface($a, $Height)
   If Not IsNumber($a) Then
	  SetError(1)
	  Return 0
   EndIf
   If Not IsNumber($Height) Then
	  SetError(2)
	  Return 0
   EndIf
   Return MathExBas_Power($a)+$a*2*Sqrt(1/4*MathExBas_Power($a)+MathExBas_Power($Height))
EndFunc ;==> MathExSTE_QuadraticPyramid_GetSurface

;### MathExSTE_QuadraticPyramid_GetVolume ##################################################################################
;Syntax ..................: MathExSTE_QuadraticPyramid_GetVolume($a, $Height)
;Beschreibung ............: Gibt das Volumen einer quadratischen Pyramide zurck
;Variablen ...............: $a					Die Kantenlnge der Grundflche der Pyramide
;							$Height				Die Hhe der Pyramide
;Rckgabe ................: Erfolg:				Das Volumen des Zylinders
;							Fehler:				0, setzt @error
;							@error:				1 	$a ist keine Zahl
;												2	$Height ist keine Zahl
;###########################################################################################################################
Func MathExSTE_QuadraticPyramid_GetVolume($a, $Height)
   If Not IsNumber($a) Then
	  SetError(1)
	  Return 0
   EndIf
   If Not IsNumber($Height) Then
	  SetError(2)
	  Return 0
   EndIf
   Return 1/3*$Height*($a*$a)
EndFunc ;==> MathExSTE_QuadraticPyramid_GetVolume

;### MathExSTE_Cone_GetVolume ##############################################################################################
;Syntax ..................: MathExSTE_Cone_GetVolume($Radius, $Height)
;Beschreibung ............: Gibt das Volumen eines Kegels zurck
;Variablen ...............: $Radius				Radius der Grundflche des Kegels
;							$Height				Hhe des Kegels
;Rckgabe ................: Erfolg:				Das Volumen des Kegels
;							Fehler:				0, setzt @error
;							@error:				1 	$Radius ist keine Zahl
;												2	$Height ist keine Zahl
;###########################################################################################################################
Func MathExSTE_Cone_GetVolume($Radius, $Height)
   If Not IsNumber($Radius) Then
	  SetError(1)
	  Return 0
   EndIf
   If Not IsNumber($Height) Then
	  SetError(2)
	  Return 0
   EndIf
   Return 1/3*MathExBas_Power($Radius)*$MATHEX_CONST_PI*$Height
EndFunc ;==> MathExSTE_Cone_GetVolume

;### MathExSTE_Cone_GetVolume ##############################################################################################
;Syntax ..................: MathExSTE_Cone_GetVolume($Radius, $Height)
;Beschreibung ............: Gibt das Volumen eines Kegels zurck
;Variablen ...............: $Radius				Radius der Grundflche des Kegels
;							$Height				Hhe des Kegels
;Rckgabe ................: Erfolg:				Das Volumen des Kegels
;							Fehler:				0, setzt @error
;							@error:				1 	$Radius ist keine Zahl
;												2	$Height ist keine Zahl
;###########################################################################################################################
Func MathExSTE_Cone_GetSurface($Radius, $Height)
   If Not IsNumber($Radius) Then
	  SetError(1)
	  Return 0
   EndIf
   If Not IsNumber($Height) Then
	  SetError(2)
	  Return 0
   EndIf
   $s=Sqrt(MathExBas_Power($Radius)+MathExBas_Power($Height))
   Return $Radius*$s*$MATHEX_CONST_PI
EndFunc ;==> MathExSTE_Cone_GetSurface

;### MathExSTE_Cone_GetCompleteSurface #####################################################################################
;Syntax ..................: MathExSTE_Cone_GetCompleteSurface($Radius, $Height)
;Beschreibung ............: Gibt die Oberflche eines Kegels zurck
;Variablen ...............: $Radius				Radius der Grundflche des Kegels
;							$Height				Hhe des Kegels
;Rckgabe ................: Erfolg:				Die Oberflche des Kegels
;							Fehler:				0, setzt @error
;							@error:				1 	$Radius ist keine Zahl
;												2	$Height ist keine Zahl
;###########################################################################################################################
Func MathExSTE_Cone_GetCompleteSurface($Radius, $Height)
   If Not IsNumber($Radius) Then
	  SetError(1)
	  Return 0
   EndIf
   If Not IsNumber($Height) Then
	  SetError(2)
	  Return 0
   EndIf
   $s=Sqrt(MathExBas_Power($Radius)+MathExBas_Power($Height))
   Return $Radius*$s*$MATHEX_CONST_PI+MathExPLA_Circle_GetSurface($Radius)
EndFunc ;==> MathExSTE_Cone_GetCompleteSurface

;### MathExSte_Cone_GetGeneratrix ##########################################################################################
;Syntax ..................: MathExSte_Cone_GetGeneratrix($Radius, $Height)
;Beschreibung ............: Gibt die Lnge der Mantellinie eines Kegels zurck
;Variablen ...............: $Radius				Radius der Grundflche des Kegels
;							$Height				Hhe des Kegels
;Rckgabe ................: Erfolg:				Die Lnge der Mantellinie eines Kegels
;							Fehler:				0, setzt @error
;							@error:				1 	$Radius ist keine Zahl
;												2	$Height ist keine Zahl
;###########################################################################################################################
Func MathExSte_Cone_GetGeneratrix($Radius, $Height)
   If Not IsNumber($Radius) Then
	  SetError(1)
	  Return 0
   EndIf
   If Not IsNumber($Height) Then
	  SetError(2)
	  Return 0
   EndIf
   Return Sqrt(MathExBas_Power($Radius)+MathExBas_Power($Height))
EndFunc ;==> MathExSte_Cone_GetGeneratrix

;### MathExSte_Cone_GetGeneratrix ##########################################################################################
;Syntax ..................: MathExSte_Cone_GetGeneratrix($Radius, $Height)
;Beschreibung ............: Gibt die Hhe eines Kegels zurck
;Variablen ...............: $Generatrix			Die Lnge der Mantellinie des Kegels
;							$Radius				Radius der Grundflche des Kegels
;Rckgabe ................: Erfolg:				Die Hhe des Kegels
;							Fehler:				0, setzt @error
;							@error:				1 	$Generatrix ist keine Zahl
;												2	$Radius ist keine Zahl
;###########################################################################################################################
Func MathExSte_Cone_GetHeight($Generatrix, $Radius)
   If Not IsNumber($Generatrix) Then
	  SetError(1)
	  Return 0
   EndIf
   If Not IsNumber($Radius) Then
	  SetError(2)
	  Return 0
   EndIf
   Return Sqrt(MathExBas_Power($Generatrix)-MathExBas_Power($Radius))
EndFunc ;==> MathExSte_Cone_GetHeight

;### MathExSte_Cone_GetRadius ##############################################################################################
;Syntax ..................: MathExSte_Cone_GetGeneratrix($Radius, $Height)
;Beschreibung ............: Gibt den Radius eines Kegels zurck
;Variablen ...............: $Generatrix			Die Lnge der Mantellinie des Kegels
;							$Height				Die Hhe der Grundflche des Kegels
;Rckgabe ................: Erfolg:				Der Radius des Kegels
;							Fehler:				0, setzt @error
;							@error:				1 	$Generatrix ist keine Zahl
;												2	$Radius ist keine Zahl
;###########################################################################################################################
Func MathExSte_Cone_GetRadius($Generatrix, $Height)
   If Not IsNumber($Generatrix) Then
	  SetError(1)
	  Return 0
   EndIf
   If Not IsNumber($Height) Then
	  SetError(2)
	  Return 0
   EndIf
   Return Sqrt(MathExBas_Power($Generatrix)-MathExBas_Power($Height))
EndFunc ;==> MathExSte_Cone_GetRadius